Stan Math Library: stan/math/prim/scal/fun/step.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

step.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_STEP_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_STEP_HPP
3
4 namespace stan {
5 namespace math {
6
28 template <typename T>
29 inline int step(const T y) {
30 return y < 0.0 ? 0 : 1;
31 }
32
33 }
34 }
35
36 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::step
int step(const T y)
The step, or Heaviside, function.
Definition: step.hpp:29

[ Stan Home Page ] © 2011–2016, Stan Development Team.